@@ -1,5 +1,8 @@
 /*
+    This file is part of KJots.
+
     Copyright (c) 2009 Montel Laurent <montel@kde.org>
+                  2020 Igor Poboiko <igor.poboiko@gmail.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,49 +22,18 @@
 #ifndef KJOTSCONFIGDLG_H
 #define KJOTSCONFIGDLG_H
 
-#include <kcmodule.h>
-#include <kcmultidialog.h>
+#include <KCModule>
+#include <KCMultiDialog>
 #include "ui_confpagemisc.h"
 
-class confPageMisc : public QWidget, public Ui::confPageMisc
-{
-    Q_OBJECT
-
-public:
-    explicit confPageMisc(QWidget *parent) : QWidget(parent)
-    {
-        setupUi(this);
-    }
-};
-
 class KJotsConfigMisc : public KCModule
 {
     Q_OBJECT
 
 public:
     explicit KJotsConfigMisc(QWidget *parent, const QVariantList &args = QVariantList());
-
-    /** Reimplemented from KCModule. */
-    virtual void load();
-
-    /** Reimplemented form KCModule. */
-    virtual void save();
-private slots:
-    void modified();
 private:
-    confPageMisc *miscPage;
-};
-
-class KJotsConfigDlg : public KCMultiDialog
-{
-    Q_OBJECT
-
-public:
-    KJotsConfigDlg(const QString &title, QWidget *parent);
-    ~KJotsConfigDlg();
-
-public slots:
-    void slotOk();
+    std::unique_ptr<Ui::confPageMisc> ui;
 };
 
 #endif /* KJOTSCONFIGDLG_H */
