@@ -26,50 +26,31 @@
 #include "aboutdata.h"
 #include "kjotswidget.h"
 
-#include <qdebug.h>
-
-//#include <kcomponentdata.h>
-//#include <kfiledialog.h>
-#include <kstandardaction.h>
-#include <KActionCollection>
-#include <kpluginfactory.h>
-#include <KLocalizedString>
-
-#include <QStatusBar>
 #include <QIcon>
-#include <QFile>
-#include <QTextStream>
-#include <QTimer>
-#include <QStandardPaths>
 #include <QAction>
 
-const KAboutData &createAboutData()
-{
-    static AboutData aboutData;
-    return aboutData;
-}
+#include <KActionCollection>
+#include <KPluginFactory>
+#include <KLocalizedString>
+
 
 K_PLUGIN_FACTORY(KJotsPartFactory, registerPlugin<KJotsPart>();)
 
 KJotsPart::KJotsPart(QWidget *parentWidget, QObject *parent, const QVariantList & /*args*/)
     : KParts::ReadOnlyPart(parent)
 {
-    // we need an instance
-    //QT5 setComponentData( KJotsPartFactory::componentData() );
-
     // this should be your custom internal widget
     mComponent = new KJotsWidget(parentWidget, this);
 
-    mStatusBar = new KParts::StatusBarExtension(this);
     // notify the part that this is our internal widget
     setWidget(mComponent);
     initAction();
 
     // set our XML-UI resource file
-    setComponentName(QStringLiteral("kjots"), QStringLiteral("kjots"));
-    setXMLFile(QStringLiteral("kjotspartui.rc"));
+    setComponentName(QStringLiteral("kjots"), i18n("KJots"));
+    setXMLFile(QStringLiteral("kjotsui.rc"));
 
-    QTimer::singleShot(0, this, SLOT(delayedInitialization()));
+    connect(mComponent, &KJotsWidget::captionChanged, this, &KJotsPart::setWindowCaption);
 }
 
 KJotsPart::~KJotsPart()
@@ -79,10 +60,9 @@ KJotsPart::~KJotsPart()
 
 void KJotsPart::initAction()
 {
-    QAction *action = new QAction(QIcon::fromTheme(QLatin1String("configure")), i18n("&Configure KJots..."), this);
-    actionCollection()->addAction(QLatin1String("kjots_configure"), action);
-    connect(action, SIGNAL(triggered(bool)), mComponent,
-            SLOT(configure()));
+    auto *action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KJots..."), this);
+    actionCollection()->addAction(QStringLiteral("kjots_configure"), action);
+    connect(action, &QAction::triggered, mComponent, &KJotsWidget::configure);
 }
 
 bool KJotsPart::openFile()
@@ -90,24 +70,4 @@ bool KJotsPart::openFile()
     return false;
 }
 
-void KJotsPart::delayedInitialization()
-{
-    connect(mComponent, SIGNAL(activeAnchorChanged(QString,QString)),
-            SLOT(activeAnchorChanged(QString,QString)));
-}
-
-void KJotsPart::activeAnchorChanged(const QString &anchorTarget, const QString &anchorText)
-{
-    if (!anchorTarget.isEmpty()) {
-        mStatusBar->statusBar()->showMessage(anchorText + QLatin1String(" -> ") + anchorTarget);
-    } else {
-        mStatusBar->statusBar()->showMessage(QString());
-    }
-}
-
-//
-// bool KJotsPart::saveFile()
-// {
-//     return false;
-// }
 #include "kjotspart.moc"
